@@ -15,6 +15,7 @@ from innoconv.ext.copy_static import CopyStatic
 from innoconv.ext.generate_toc import GenerateToc
 from innoconv.ext.index_terms import IndexTerms
 from innoconv.ext.join_strings import JoinStrings
+from innoconv.ext.number_boxes import NumberBoxes
 from innoconv.ext.tikz2svg import Tikz2Svg
 from innoconv.ext.write_manifest import WriteManifest
 
@@ -24,6 +25,7 @@ EXTENSIONS = {
     "generate_toc": GenerateToc,
     "index_terms": IndexTerms,
     "join_strings": JoinStrings,
+    "number_boxes": NumberBoxes,
     "tikz2svg": Tikz2Svg,
     "write_manifest": WriteManifest,
 }
